@@ -34,8 +34,8 @@ def _load_patterns(views, patterns, namespace=None):
         if isinstance(pattern, RegexURLPattern):
             _load_pattern(views, pattern, namespace)
         elif isinstance(pattern, RegexURLResolver):
-            if namespace and hasattr(patterns, 'namespace'):
-                namespace += ':' + patterns.namespace
+            if namespace and hasattr(pattern, 'namespace'):
+                namespace += ':' + pattern.namespace
             elif hasattr(pattern, 'namespace'):
                 namespace = pattern.namespace
             _load_patterns(views, pattern.url_patterns, namespace)
